@@ -13,11 +13,11 @@
     license reproduced at the end of this file.
 =============================================================================*/
 
-// Tests error reporting: ill-formed group in a source file. 
+// Tests error reporting: #ifdef, #ifndef syntax errors.
 
-// 17.6: Errorneous unterminated #if section in an included file.
-//E t_6_030.hpp(49): warning: unbalanced #if/#endif in include file: $P(t_6_030.hpp)
-#include "t_6_030.hpp"
+// 15.5: No argument. 
+//E t_6_022.cpp(20): error: ill formed preprocessor directive: #ifndef
+#ifndef
 #endif
 
 /*-
